#
# spec file for package libevt
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname	libevt1
Name:           libevt
Version:        20210503
Release:        bp154.2.19
Summary:        Library and tools to access the Windows Event Log (EVT) format
License:        GFDL-1.3-or-later AND LGPL-3.0-or-later
Group:          Productivity/File utilities
URL:            https://github.com/libyal/libevt
Source:         %name-%version.tar.xz
Source2:        Windows_Event_Log_EVT.pdf
Patch1:         system-libs.patch
BuildRequires:  %{python_module devel}
BuildRequires:  c_compiler
BuildRequires:  gettext-tools >= 0.18.1
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(libbfio) >= 20201229
BuildRequires:  pkgconfig(libcdata) >= 20200509
BuildRequires:  pkgconfig(libcdirectory) >= 20200702
BuildRequires:  pkgconfig(libcerror) >= 20201121
BuildRequires:  pkgconfig(libcfile) >= 20201229
BuildRequires:  pkgconfig(libclocale) >= 20200913
BuildRequires:  pkgconfig(libcnotify) >= 20200913
BuildRequires:  pkgconfig(libcpath) >= 20200623
BuildRequires:  pkgconfig(libcsplit) >= 20200703
BuildRequires:  pkgconfig(libcthreads) >= 20200508
BuildRequires:  pkgconfig(libexe) >= 20210424
BuildRequires:  pkgconfig(libfcache) >= 20200708
BuildRequires:  pkgconfig(libfdata) >= 20201129
BuildRequires:  pkgconfig(libfdatetime) >= 20180910
BuildRequires:  pkgconfig(libfguid) >= 20180724
BuildRequires:  pkgconfig(libfvalue) >= 20210510
BuildRequires:  pkgconfig(libfwevt) >= 20210508
BuildRequires:  pkgconfig(libfwnt) >= 20210421
BuildRequires:  pkgconfig(libregf) >= 20210419
BuildRequires:  pkgconfig(libuna) >= 20201204
BuildRequires:  pkgconfig(libwrc) >= 20210425
BuildRequires:  pkgconfig(python3)
%python_subpackages

%description
libevt is a library and tools to access the Windows Event Log
(EVT) format.
For the Windows XML Event Log (EVTX) format, see libevtx.

%package -n %lname
Summary:        Library to access the Windows Event Log (EVT) format
License:        LGPL-3.0-or-later
Group:          System/Libraries

%description -n %lname
libevt is a library and tools to access the Windows Event Log
(EVT) format.
For the Windows XML Event Log (EVTX) format, see libevtx.

%package tools
Summary:        Utilities to export events from Windows Event Log files
License:        LGPL-3.0-or-later
Group:          Productivity/File utilities

%description tools
Tools for reading Windows Event Log (EVT) files. These include
evtinfo and evtexport. See evtxtools for Windows XML Event Log (EVTX)
programs.

%package devel
Summary:        Development files for libevt, a Windows event file parser
License:        GFDL-1.3-or-later AND LGPL-3.0-or-later
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
libevt is a library to access the Windows Event Log (EVT) format.

This subpackage contains libraries and header files for developing
applications that want to make use of %name.

%prep
%autosetup -p1
cp "%SOURCE2" .

%build
autoreconf -fi
# OOT builds are presently broken, so we have to install
# within each python iteration now, not in %%install.
%{python_expand #
%configure --disable-static --enable-wide-character-type \
	--enable-python PYTHON_VERSION="%{$python_bin_suffix}"
%make_build
%make_install DESTDIR="%_builddir/rt"
%make_build clean
}

%install
mv %_builddir/rt/* %buildroot/
find %{buildroot} -type f -name "*.la" -delete -print

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%license COPYING*
%_libdir/libevt.so.*

%files -n %name-tools
%_bindir/evt*
%_mandir/man1/evt*.1*

%files -n %name-devel
%doc Windows_Event_Log*.pdf
%license COPYING*
%_includedir/libevt.h
%_includedir/libevt/
%_libdir/libevt.so
%_libdir/pkgconfig/libevt.pc
%_mandir/man3/libevt.3*

%files %python_files
%license COPYING*
%python_sitearch/pyevt.so

%changelog
* Fri Jan 21 2022 Jan Engelhardt <jengelh@inai.de>
- Edit specfile to do multipython builds.
* Sat Jun 26 2021 Jan Engelhardt <jengelh@inai.de>
- Drop python2 module build.
* Thu May 13 2021 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 20210503 (bc1ed1a6)
  * No changelog was provided
- Add system-libs.patch
* Thu Dec 24 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to 0~20200926
  * Changes to ensure record data can wrap only once in a record scan
  * Code clean up
* Tue May  5 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Allow distros to disable py2 support (bcond_without). Tumbleweed
  declares this, as py2 is EOL.
* Mon Apr  6 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to 0~20191221
  * Code clean up
  * added thread lock support
- add python3 support
* Thu Mar 28 2019 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to 0~20181227
  * worked on python bindings
  * code clean-up
  * miscelaneos small fixes
* Wed Jan 27 2016 Greg.Freemyer@gmail.com
- update to 0~20160107
  * 2016 update
  * worked on Python 3 support
  * applied updates
  * updated libfwnt
  * worked on Python bindings
  * worked on tests
  * worked on setup.py
  * worked on check signature
  * bug fixes
- use internal versions of libcerror, libfvalue, and libfwnt
* Mon Jan 12 2015 Greg.Freemyer@gmail.com
- update to 0~20150105
  * 2015 update
  * worked on Python 3 support
  * worked on tests
  * code clean up
  * update Python-bindings tests
- update URL to the new github site
- update Source: to the new github site
- start using newly released libyal packages from OBS, not internal version
* Fri Sep 19 2014 Greg.Freemyer@gmail.com
- update to 0~20140831
  * bug fix in Python-bindings
- update Source: field to fullpath, delete DL_URL
- add these 2 lines to python sub-project to ensure proper syncronization between versions
  * Requires:     %%lname = %%version
  * Provides:	pyevt = %%version
* Wed Aug 13 2014 Greg.Freemyer@gmail.com
- update to 0~20140731
  * worked on Python-bindings
  * bug fix in Python-bindings
  * updated dependencies
  * replaced PackageMaker for pkgbuild
  * bug fix for strings offset correction if member data > 0
  * code clean up
  * worked on setup.py
  * removed examples
  * bug fix in check signature
  * 2014 update
  * small fix in evtexport -h output
* Thu Nov 14 2013 Greg.Freemyer@gmail.com
- update to 0~20131013
  * worked on setup.py, largely for MSI builds
  * updated dependencies
  * worked on libcthreads build support
- use libcthreads and libcfile from factory
* Wed Jul 31 2013 Greg.Freemyer@gmail.com
- update to 0~20130727
  * updated dependencies
  * pyevt
  - changed event identifier to an unsigned long
  - fixes fro >2G file objects in BFIO glue code
  * worked on tests
  * bug fix for wrapped event record
  * fixed codepage 1255 restriction
  * updates and bug fixes in pyevt
  * implemented libfdata support to improve handling of large EVT files
  * remove item flags
  * added support for truncated event record corruption scenario
  * fixed codepage 949 and 950 restriction
- change to gz compression to simplyfy download/convert
- use libyal factory packages if possible
* Wed Apr  3 2013 jengelh@inai.de
- Cleanups: Set RPM group, license, summary and description
  metadata; remove unused %%py_requires; do not bloat shlib package
  with documentation
- Use system libraries instead of bundled ones where possible
- Name the tools package according to upstream's recommendation
- Drop unnecessary -fno-strict-aliasing
* Wed Mar 27 2013 Greg.Freemyer@gmail.com
- initial package (version 0~20130319) for build.opensuse.org
